#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os, errno
import re
import sys
import time
import datetime
import gzip
import glob
import json

from datetime import datetime
from pprint import pprint
from optparse import make_option
from os.path import expanduser
from django.core.management.base import BaseCommand, CommandError
from django.template import Context, Template
from django.conf import settings as conf
from django.utils import timezone

import rstamper.models as mymodels


# Class MUST be named 'Command'
class Command(BaseCommand):

    # Displayed from 'manage.py help mycommand'
    help = """
    Tool that tries to import stamps from a .json file:

    ./manage.py import

    """

    option_list = BaseCommand.option_list + (
            make_option(
                '--file',
                dest='file',
                default=expanduser('~/.workstamps.json'),
                help='File to import (~/.workstamps.json by default)'
            ),
        )

    def handle(self, *app_labels, **options):
        """
        The command itself
        """

        with open(options['file'], 'r') as f:
            json_data = json.load(f)

        # Deleting customers and stamps
        mymodels.Customer.objects.all().delete()
        mymodels.Stamp.objects.all().delete()

        # Special customer
        cus = mymodels.Customer(name='None')
        cus.save()

        for stamp in json_data:
            if stamp['customer']:
                try:
                    cus = mymodels.Customer(name=stamp['customer'])
                    cus.save()
                    print "[+] Customer: %s" % stamp['customer']
                except:
                    cus = mymodels.Customer.objects.get(name=stamp['customer'])
            else:
                cus = mymodels.Customer.objects.get(name='None')

            try:
                start = None
                end = None
                if stamp['start'] and stamp['end']:
                    if stamp['start']:
                        start = datetime.strptime(stamp['start'], '%Y-%m-%d %H:%M')
                        start=timezone.make_aware(start, timezone.get_current_timezone())
                    if stamp['end']:
                        end = datetime.strptime(stamp['end'], '%Y-%m-%d %H:%M')
                        end=timezone.make_aware(end, timezone.get_current_timezone())
                    stamp = mymodels.Stamp(
                        action=stamp['action'],
                        customer=cus,
                        start=start,
                        end=end,
                        )
                    stamp.save()
            except Exception as e:
                print "Error: %s" % e



# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Customer'
        db.create_table('rstamper_customer', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=255)),
        ))
        db.send_create_signal('rstamper', ['Customer'])

        # Adding model 'Stamp'
        db.create_table('rstamper_stamp', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('action', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('customer', self.gf('django.db.models.fields.related.ForeignKey')(related_name='customer', to=orm['rstamper.Customer'])),
            ('start', self.gf('django.db.models.fields.DateTimeField')()),
            ('end', self.gf('django.db.models.fields.DateTimeField')()),
        ))
        db.send_create_signal('rstamper', ['Stamp'])


    def backwards(self, orm):
        # Deleting model 'Customer'
        db.delete_table('rstamper_customer')

        # Deleting model 'Stamp'
        db.delete_table('rstamper_stamp')


    models = {
        'rstamper.customer': {
            'Meta': {'object_name': 'Customer'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '255'})
        },
        'rstamper.stamp': {
            'Meta': {'object_name': 'Stamp'},
            'action': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'customer': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'customer'", 'to': "orm['rstamper.Customer']"}),
            'end': ('django.db.models.fields.DateTimeField', [], {}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'start': ('django.db.models.fields.DateTimeField', [], {})
        }
    }

    complete_apps = ['rstamper']


#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os, errno
import re
import sys
import time
import datetime
import gzip
import glob
import json

import requests

from datetime import datetime
from pprint import pprint
from optparse import make_option
from os.path import expanduser
from django.core.management.base import BaseCommand, CommandError
from django.template import Context, Template
from django.conf import settings as conf
from django.utils import timezone

import rstamper.models as mymodels


# Class MUST be named 'Command'
class Command(BaseCommand):

    # Displayed from 'manage.py help mycommand'
    help = """
    Tool that tries to export stamps from a .json file:

    ./manage.py export

    """

    option_list = BaseCommand.option_list + (
            make_option(
                '--file',
                dest='file',
                default=expanduser('~/.workstamps.json'),
                help='File to import (~/.workstamps.json by default)'
            ),
            make_option(
                '--remote',
                default='http://oscarmlage.com/stamper/api/',
                dest='remote',
                help='API URL to export data'
            ),
        )

    def handle(self, *app_labels, **options):
        """
        The command itself
        """
        headers = {'content-type': 'application/json'}

        # Customers
        url = options['remote'] + 'customers/'
        cus = mymodels.Customer.objects.all()
        data = {}
        remotedata = {}
        for c in cus:
            data = {'name': c.name}
            res = requests.post(url, data=json.dumps(data), headers=headers)
            resdata = json.loads(res.content)
            try:
                remotedata[resdata['id']] = resdata['name']
            except:
                pass
            #print res.status_code
            #print res.content

        # Stamps
        url = options['remote'] + 'stamps/'
        stamps = mymodels.Stamp.objects.all()
        data = {}
        for stamp in stamps:
            for k,v in remotedata.items():
                if v == stamp.customer.name:
                    customer = k
            data = {
                'action': stamp.action,
                'customer': customer,
                'start': stamp.start.strftime("%Y-%m-%d %H:%M"),
                'end': stamp.end.strftime("%Y-%m-%d %H:%M"),
            }
            res = requests.post(url, data=json.dumps(data), headers=headers)
            #print res.status_code
            #print res.content




# -*- coding: utf-8 -*-

"""
Models for the "rstamper" project
"""

import time
import socket
from django.db import models
from django.contrib.auth.models import User
from django.utils.translation import ugettext_lazy as _
from django.contrib.contenttypes import generic
from django.template.defaultfilters import slugify
from django.conf import settings as conf

from rtimes import worktime, humanize_time


class Customer(models.Model):

    """
    Modelo that defines a customer.
    """

    name = models.CharField(_(u'Customer'), max_length=255, unique=True)

    def __unicode__(self):
        return str(self.name)

    class Meta:
        verbose_name = _(u'Customer')
        verbose_name_plural = _(u'Customers')


class Stamp(models.Model):

    """
    Modelo that defines a stamp.
    """

    action = models.TextField(_(u'Action'), max_length=255, null=True)
    customer = models.ForeignKey(Customer, related_name='customer')
    start = models.DateTimeField(_(u'Start date'))
    end = models.DateTimeField(_(u'End date'), null=True)

    def __unicode__(self):
        return "[%s - %s] %s - %s" % (self.start, self.end, self.customer,
                                      self.action)

    def mins(self):
        mins = worktime(self.start.strftime("%Y-%m-%d %H:%M"),
                        self.end.strftime("%Y-%m-%d %H:%M"))
        return humanize_time(mins)

    class Meta:
        verbose_name = _(u'Stamp')
        verbose_name_plural = _(u'Stamps')




# -*- coding: utf-8 -*-

from django.conf.urls.defaults import *
from rstamper.views import Stamps, Refresh, CustomersApi, StampsApi

urlpatterns = patterns('',
    url(
        r'^$',
        Stamps.as_view(),
        name='app_stamper-stamper'),
    url(
        r'^stamper/ajax/refresh$',
        Refresh.as_view(),
        name='app_stamper-refresh'
    ),
    url(
        r'^stamper/api/customers/$',
        CustomersApi.as_view(),
        name='app_stamper-api-customers'
    ),
    url(
        r'^stamper/api/stamps/$',
        StampsApi.as_view(),
        name='app_stamper-api-stamps'
    ),

)



# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding unique constraint on 'Customer', fields ['name']
        db.create_unique('rstamper_customer', ['name'])


    def backwards(self, orm):
        # Removing unique constraint on 'Customer', fields ['name']
        db.delete_unique('rstamper_customer', ['name'])


    models = {
        'rstamper.customer': {
            'Meta': {'object_name': 'Customer'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '255'})
        },
        'rstamper.stamp': {
            'Meta': {'object_name': 'Stamp'},
            'action': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'customer': ('django.db.models.fields.related.ForeignKey', [], {'related_name': "'customer'", 'to': "orm['rstamper.Customer']"}),
            'end': ('django.db.models.fields.DateTimeField', [], {}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'start': ('django.db.models.fields.DateTimeField', [], {})
        }
    }

    complete_apps = ['rstamper']


# -*- coding: utf-8 -*-
from setuptools import setup, find_packages

setup(
    name='django-rstamper',
    version='0.0.6',
    author=u'Oscar M. Lage Guitian',
    author_email='r0sk10@gmail.com',
    #packages=['rstamper'],
    packages = find_packages(),
    include_package_data = True,
    package_data = {'': ['rstamper/templates', 'rstamper/static','rstamper/fixtures',], 'rstamper-example': ['rstamper-example/*']},
    url='http://bitbucket.org/r0sk/django-rstamper',
    license='BSD licence, see LICENSE file',
    description='Yet another Django Gallery App',
    zip_safe=False,
    long_description=open('README.rst').read(),
    install_requires=[
        "Django < 1.5",
        "South == 0.7.5",
        "djangorestframework == 2.4.3",
        "djangorestframework-bulk == 0.1.3",
        "requests == 2.4.3",
    ],
    keywords = "django application stamper",
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)



# -*- coding: utf-8 -*-

import os.path
from django.contrib import admin
from django.utils.safestring import mark_safe

import models as mymodels


class StampAdmin(admin.ModelAdmin):
    list_display = ('customer', 'start', 'end', 'customer', 'action')
    search_fields = ('customer', 'action', )


admin.site.register(mymodels.Stamp, StampAdmin)
admin.site.register(mymodels.Customer)
